from __future__ import (absolute_import, division,print_function)
import maya.cmds as cmds
from .. import rigSettings,rigUtil
##モジュールの種類
_MODULETYPE = "ctrl"

##アトリビュート名リスト
_ATTRS = [
                ##固有アトリビュート
                "joint" #コントローラーを追従させるjoint

]

##アトリビュートのタイプ　デフォルト値などオプションを定義
_ATTR_DICT = {
                "joint":  {"type":"message",  "multi":False,  "default":""},
}

##--------------------------------------------------------------------------------------------
def setup(section,side,joint,globalScale,**kwargs):
    sideString = rigUtil.getSideString(side)

    ##ctrl　name/shape/scale/color は固定
    ctrlScale = globalScale*0.5
    ctrlShape = "diamond"
    ctrlName = "PM_" + section + sideString + rigSettings.SUFFIX_DICT["ctrl"]
    ctrlColor = "green"

    if joint == "":
        joint = None
        
    if cmds.objExists(ctrlName) == False:
        parentJoint = rigSettings.NODENAME_DICT["rootJNT"]
        if joint != None:
            parentJoint = cmds.listRelatives(joint,p=True)[0]

        parentProxy = rigSettings.NODENAME_DICT["ctrlWorldSpace"]

        if parentJoint != rigSettings.NODENAME_DICT["rootJNT"]:        
            parentProxy = rigUtil.createParentProxy(parentJoint,rigSettings.NODENAME_DICT["ctrlWorldSpace"],attrs = ["t","r","s"])

        ctrlNode = rigUtil.createCtrlNode(
                                        ctrlName,
                                        ctrlShape,
                                        "joint",
                                        size = ctrlScale,
                                        position = joint,
                                        rotation =joint
                                    )

        cmds.parent(ctrlNode,parentProxy,a=True)

        ##不要なアトリビュートをロック  
        lockAttrs = ["t","r","s","v"]  
        rigUtil.setAttrState([ctrlNode],lockAttrs,True,True,False)

        ##コントローラーの色を設定
        rigUtil.setWireFrameColor([ctrlNode],ctrlColor, 1.0)
            
        ##コントローラーを setsへ登録
        ##setsをsection毎に分割
        rigUtil.addToSet(rigSettings.NODENAME_DICT["allCtrlSet"] + "|" + section + "Ctrl" + rigSettings.SUFFIX_DICT["set"],[ctrlNode])


    return ctrlName

def main(**kwargs):
    
    setup(**kwargs)

    return 